@@ -49,7 +49,7 @@ class TestBasicFunctionalityTags(TestCase):
 
         c = Context({'form': form})
         html = template.render(c)
-        self.assertFalse("errorMsg" in html)
+        self.assertFalse("errorMsg" in html or "alert-message" in html)
 
     def test_as_crispy_errors_form_with_non_field_errors(self):
         template = get_template_from_string(u"""
@@ -61,7 +61,7 @@ class TestBasicFunctionalityTags(TestCase):
 
         c = Context({'form': form})
         html = template.render(c)
-        self.assertTrue("errorMsg" in html)
+        self.assertTrue("errorMsg" in html or "alert-message" in html)
         self.assertTrue("<li>Passwords dont match</li>" in html)
         self.assertFalse("<h3>" in html)
 
@@ -121,15 +121,16 @@ class TestFormHelpers(TestCase):
         c = Context({'form': TestForm(), 'form_helper': form_helper})        
         html = template.render(c)
 
-        self.assertTrue('class="submit submitButton button white"' in html)
+        self.assertTrue('button white' in html)
+        self.assertTrue('submit submitButton' in html or 'btn' in html)
         self.assertTrue('id="submit-id-my-submit"' in html)        
 
-        self.assertTrue('class="reset resetButton"' in html)
+        self.assertTrue('reset resetButton' in html)
         self.assertTrue('id="reset-id-my-reset"' in html)        
 
         self.assertTrue('name="my-hidden"' in html)        
 
-        self.assertTrue('class="button"' in html)
+        self.assertTrue('button' in html)
         self.assertTrue('id="button-id-my-button"' in html)        
 
     def test_invalid_helper_method(self):
@@ -161,12 +162,10 @@ class TestFormHelpers(TestCase):
         
         # Lets make sure everything loads right
         self.assertTrue(html.count('<form'), 1)
-        self.assertTrue('class="uniForm forms-that-rock"' in html)
+        self.assertTrue('forms-that-rock' in html)
         self.assertTrue('method="get"' in html)
         self.assertTrue('id="this-form-rocks">' in html)
         self.assertTrue('action="%s"' % reverse('simpleAction') in html)
-        self.assertEqual(html.count('<fieldset'), 1)
-
 
         self.assertTrue("<h3>ERRORS</h3>" in html)
         self.assertTrue("<li>Passwords dont match</li>" in html)
@@ -176,10 +175,40 @@ class TestFormHelpers(TestCase):
         form_helper.form_tag = False 
         html = template.render(c)        
         self.assertFalse('<form' in html)        
-        self.assertFalse('class="uniForm forms-that-rock"' in html)
+        self.assertFalse('forms-that-rock' in html)
         self.assertFalse('method="get"' in html)
         self.assertFalse('id="this-form-rocks">' in html)
 
+    def test_crispy_tag_with_helper_form_show_errors(self):
+        form = TestForm({'password1': 'wargame', 'password2': 'god'})
+        form.helper = FormHelper()
+        form.helper.form_show_errors = True
+        form.is_valid()
+
+        template = get_template_from_string(u"""
+            {% load crispy_forms_tags %}
+            {% crispy testForm %}
+        """)
+
+        # First we render with errors
+        c = Context({'testForm': form})
+        html = template.render(c)
+
+        # Ensure those errors were rendered
+        self.assertTrue('<li>Passwords dont match</li>' in html)
+        self.assertTrue('This field is required.' in html)
+        self.assertTrue('error' in html)
+
+        # Now we render without errors
+        form.helper.form_show_errors = False
+        c = Context({'testForm': form})
+        html = template.render(c)
+
+        # Ensure errors were not rendered
+        self.assertFalse('<li>Passwords dont match</li>' in html)
+        self.assertFalse('This field is required.' in html)
+        self.assertFalse('error' in html)
+
     def test_crispy_tag_without_helper(self):
         template = get_template_from_string(u"""
             {% load crispy_forms_tags %}
@@ -190,7 +219,6 @@ class TestFormHelpers(TestCase):
         
         # Lets make sure everything loads right
         self.assertTrue('<form' in html)
-        self.assertTrue('class="uniForm"' in html)
         self.assertTrue('method="post"' in html)
         self.assertFalse('action' in html)
 
@@ -201,12 +229,12 @@ class TestFormHelpers(TestCase):
         """)
         c = Context({'form': TestForm(), 'form_helper': "invalid"})
 
-        settings.UNIFORM_FAIL_SILENTLY = False
+        settings.CRISPY_FAIL_SILENTLY = False
         if settings.TEMPLATE_DEBUG:
             self.assertRaises(TemplateSyntaxError, lambda:template.render(c))
         else:
             self.assertRaises(TypeError, lambda:template.render(c))
-        del settings.UNIFORM_FAIL_SILENTLY
+        del settings.CRISPY_FAIL_SILENTLY
 
     def test_crispy_tag_formset_with_helper_without_layout(self):
         template = get_template_from_string(u"""
@@ -234,7 +262,7 @@ class TestFormHelpers(TestCase):
         self.assertTrue('form-INITIAL_FORMS' in html)
         self.assertTrue('form-MAX_NUM_FORMS' in html)
     
-        self.assertTrue('class="uniForm formsets-that-rock"' in html)
+        self.assertTrue('formsets-that-rock' in html)
         self.assertTrue('method="post"' in html)
         self.assertTrue('id="thisFormsetRocks">' in html)
         self.assertTrue('action="%s"' % reverse('simpleAction') in html)
@@ -285,9 +313,9 @@ class TestFormLayout(TestCase):
             {% crispy form form_helper %}
         """)        
         c = Context({'form': TestForm(), 'form_helper': form_helper})
-        settings.UNIFORM_FAIL_SILENTLY = False
+        settings.CRISPY_FAIL_SILENTLY = False
         self.assertRaises(Exception, lambda:template.render(c))
-        del settings.UNIFORM_FAIL_SILENTLY
+        del settings.CRISPY_FAIL_SILENTLY
 
     def test_layout_unresolved_field(self):
         form = TestForm()
@@ -304,9 +332,9 @@ class TestFormLayout(TestCase):
             {% crispy form form_helper %}
         """)        
         c = Context({'form': TestForm(), 'form_helper': form_helper})
-        settings.UNIFORM_FAIL_SILENTLY = False
+        settings.CRISPY_FAIL_SILENTLY = False
         self.assertRaises(Exception, lambda:template.render(c))
-        del settings.UNIFORM_FAIL_SILENTLY
+        del settings.CRISPY_FAIL_SILENTLY
 
     def test_double_rendered_field(self):
         form = TestForm()
@@ -323,9 +351,9 @@ class TestFormLayout(TestCase):
             {% crispy form form_helper %}
         """)        
         c = Context({'form': TestForm(), 'form_helper': form_helper})
-        settings.UNIFORM_FAIL_SILENTLY = False
+        settings.CRISPY_FAIL_SILENTLY = False
         self.assertRaises(Exception, lambda:template.render(c))
-        del settings.UNIFORM_FAIL_SILENTLY
+        del settings.CRISPY_FAIL_SILENTLY
 
     def test_layout_fieldset_row_html_with_unicode_fieldnames(self):
         form_helper = FormHelper()
@@ -543,7 +571,7 @@ class TestFormLayout(TestCase):
         self.assertEqual(html.count('<form'), 1)
         self.assertEqual(html.count("<input type='hidden' name='csrfmiddlewaretoken'"), 1)
 
-        self.assertTrue('class="uniForm formsets-that-rock"' in html)
+        self.assertTrue('formsets-that-rock' in html)
         self.assertTrue('method="post"' in html)
         self.assertTrue('id="thisFormsetRocks">' in html)
         self.assertTrue('action="%s"' % reverse('simpleAction') in html)
