@@ -5,11 +5,13 @@ from django.conf import settings
 from django.forms.forms import BoundField
 from django.template import Context
 from django.template.loader import get_template
+from django.forms.util import flatatt
 
 
 # Global field template, default template used for rendering a field. This way we avoid 
 # loading the template every time render_field is called without a template
-default_field_template = get_template("uni_form/field.html")
+TEMPLATE_PACK = getattr(settings, 'CRISPY_TEMPLATE_PACK', 'bootstrap')
+default_field_template = get_template("%s/field.html" % TEMPLATE_PACK)
 
 def render_field(field, form, form_style, context, template=None, labelclass=None, layout_object=None, attrs=None):
     """
@@ -32,7 +34,7 @@ def render_field(field, form, form_style, context, template=None, labelclass=Non
 
     :attrs: Attributes for the field's widget
     """
-    FAIL_SILENTLY = getattr(settings, 'UNIFORM_FAIL_SILENTLY', True)
+    FAIL_SILENTLY = getattr(settings, 'CRISPY_FAIL_SILENTLY', True)
 
     if hasattr(field, 'render'):
         return field.render(form, form_style, context)
@@ -81,7 +83,8 @@ def render_field(field, form, form_style, context, template=None, labelclass=Non
         # We save the Layout object's bound fields in the layout object's `bound_fields` list
         if layout_object is not None:
             layout_object.bound_fields.append(bound_field) 
-        
-        html = template.render(Context({'field': bound_field, 'labelclass': labelclass}))
+       
+        context.update({'field': bound_field, 'labelclass': labelclass, 'flat_attrs': flatatt(attrs or {})})
+        html = template.render(context)
 
     return html
